ProSHADE: Class Members

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Here is a list of all documented class members with links to the class documentation for each member:

### - i -

- inputFiles : ProSHADE_settings
- inputOrder : ProSHADE_internal_data::ProSHADE_data
- integOrder : ProSHADE_settings
- integrationWeight : ProSHADE_internal_data::ProSHADE_data
- internalMap : ProSHADE_internal_data::ProSHADE_data
- interpolateAlongFirst() : ProSHADE_internal_spheres::ProSHADE_sphere
- interpolateAlongSecond() : ProSHADE_internal_spheres::ProSHADE_sphere
- interpolateMapFromSpheres() : ProSHADE_internal_data::ProSHADE_data
- interpolateSphereValues() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- invertMap : ProSHADE_settings
- invertMirrorMap() : ProSHADE_internal_data::ProSHADE_data
- invertSHCoefficients() : ProSHADE_internal_data::ProSHADE_data
- isEmpty : ProSHADE_internal_data::ProSHADE_data